#coding: utf-8

class Article < ActiveRecord::Base
  has_many :comments
  has_many :users, :through => :comments
  has_and_belongs_to_many :authors
  has_many :photos, :as => :photoable

  validates :url,
    :presence => { :message => 'は必ず入力してください。' },
    :uniqueness => { :message => '「%{value}」が重複しています。' },
    :length => { :maximum => 255,
      :too_long => 'は%{count}文字以内で入力してください。' },
    :format => { :with => /^http(s)?:\/\/([\w\-]+\.)+[\w\-]+(\/[\w\- .\/?%&=]*)?$/, :message => 'はURL形式で入力してください。' }
  validates :title,
    #:presence => true,
    :length => { :in => 5..100, :allow_blank => true }
  validates :category,
    :inclusion => { :in => ['Script', '.NET', 'Ruby', 'Other' ],
      :allow_blank => true }
  validates :access,
    :numericality => { :only_integer => true,
      :greater_than => 0, :allow_blank => true }

  scope :script, where(:category => 'Script')
  scope :recent, order('published DESC')
  scope :whats_new5, recent.limit(5)
  scope :whats_new, lambda {
    |c, n| where(:category => c).order('published DESC').limit(n) }

  #self.per_page=3

  #after_save :history_article,
  #  :unless => Proc.new { |a| a.closed == true }

  #after_save :unless => Proc.new { |a| a.closed == true } do |a|
  #  logger.info('saved: ' + a.inspect)
  #end

  #after_save 'logger.info("saved: " + self.inspect)',
  #  :unless => Proc.new { |a| a.closed == true }

  #after_save ArticleCallback.new, :unless => Proc.new { |a| a.closed == true }

  #after_find :after_ini

  private
  def after_ini
    logger.info('get: ' + self.inspect)
  end

  def history_article
    logger.info('saved: ' + self.inspect)
  end
end
