#coding: utf-8

class User < ActiveRecord::Base
  has_many :comments
  has_many :articles, :through => :comments
  has_one :author

  # attr_protected :roles
  # attr_accessible :name, :password, :kname, :email
  # attr_accessible :name, :password, :kname, :email, :roles, :as => :admin

  validates :name,
    :presence => true,
    :uniqueness => true,
    :length => { :maximum => 20 }
  validates :password,
    :equals => { :compare_field => 'name', :type => :not_equal },
    :length => { :in => 6..40 },
    :format => { :with => /^[0-9A-Za-z_@%]{4,}$/ },
    :confirmation => true
    
  validates :agreement, :acceptance => { :on => :create }
  validates :email,
    #:email => true,
    :presence => { :if => 'roles != "guest"' }
    #:presence => { :unless => 'roles == "guest"' }
    #:presence => { :if => Proc.new { |u| u.roles != 'guest' } }
    #:presence => { :if => :is_not_guest? }
  #validate :email_valid?
  validates_each :name, :password do |record, attr, value|
    record.errors.add(attr, 'は英数字、記号（_@%）のみで指定してください。') unless value =~ /^[0-9A-Za-z_@%]{4,}$/
  end

  private
  def is_not_guest?
    roles != 'guest'
  end

  def email_valid?
    errors.add(:email, 'はメールアドレスの形式で入力してください。') unless email =~ /^\w+([\-+.']\w+)*@\w+([\-.]\w+)*\.\w+([\-.]\w+)*$/
  end
end
