#coding: utf-8
require 'test_helper'

class ArticlesControllerTest < ActionController::TestCase

  test "index action" do
    get :index
    assert_response :success, 'index action failed'
    assert_template 'articles/index', 'index template missing'
  end

  test "show action" do
    get :show, { :id => 1 }
    assert_equal @controller.controller_name, 'articles'
    assert_response :success
    assert_not_nil assigns(:article)
  end

  test "update action" do
    put :update, :id => 1,
      :article => { :title => 'ASP.NET MVC3入門', :category => 'Script' }
    assert_equal assigns(:article).category, 'Script'
    assert_redirected_to article_path(1)
  end

  test "destroy action" do
    assert_difference('Article.count', -1) do
      delete :destroy, :id => 1
    end
    assert_redirected_to articles_path
  end

  test "create action" do
    assert_difference('Article.count') do
      post :create,
        :article => {
           :url => 'http://itpro.nikkeibp.co.jp/article/COLUMN/20060529/239205/',
           :title => '今からでも遅くない Ajax基本のキ', :category => 'Script' }
    end
    assert_redirected_to article_path(assigns(:article))
  end

  test "create action fail" do
    assert_no_difference('Article.count') do
      post :create,
        :article => {
          :url => '@railsref/index.html',
          :title => 'Railsリファレンス',
          :category => 'Script' }
    end
    assert_template 'articles/new'
  end

  test "routing check" do
    assert_generates('articles/1',
      :controller => 'articles', :action => 'show', :id => 1)
    assert_recognizes(
      { :controller => 'articles', :action => 'edit', :id => '1' },
      'articles/1/edit')
  end

  test "select check" do
    get :index
    assert_select 'script'
    assert_select 'script', true
    assert_select 'center', false
    assert_select 'title', 'Railsample'
    assert_select 'h1', /[A-Za-z0-9 ]+/
    assert_select 'script[type=?]', /.+/
    assert_select 'script', :minimum => 1, :maximum => 5
    assert_select 'table tr', 11
    assert_select 'table' do
      assert_select 'tr', 11
    end
  end

  #setup do
  #  @article = articles(:one)
  #end

  #test "should get index" do
  #  get :index
  #  assert_response :success
  #  assert_not_nil assigns(:articles)
  #end

  #test "should get new" do
  #  get :new
  #  assert_response :success
  #end

  #test "should create article" do
  #  assert_difference('Article.count') do
  #    post :create, article: @article.attributes
  #  end

  #  assert_redirected_to article_path(assigns(:article))
  #end

  #test "should show article" do
  #  get :show, id: @article.to_param
  #  assert_response :success
  #end

  #test "should get edit" do
  #  get :edit, id: @article.to_param
  #  assert_response :success
  #end

  #test "should update article" do
  #  put :update, id: @article.to_param, article: @article.attributes
  #  assert_redirected_to article_path(assigns(:article))
  #end

  #test "should destroy article" do
  #  assert_difference('Article.count', -1) do
  #    delete :destroy, id: @article.to_param
  #  end

  #  assert_redirected_to articles_path
  #end
end
